@@ -1,20 +1,17 @@
-/* 
- * Copyright 2000-2004 by Hans Reiser, licensing governed by 
+/*
+ * Copyright 2000-2004 by Hans Reiser, licensing governed by
  * reiserfsprogs/README
  */
 
-#define _GNU_SOURCE
+#ifndef HAVE_CONFIG_H
+#  include "config.h"
+#endif
 
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <asm/types.h>
-#include <errno.h>
-#include <stdio.h>
-#include <mntent.h>
-#include <string.h>
-#include <unistd.h>
-#include <fcntl.h>
-#include <stdlib.h>
+#include "io.h"
+#include "misc.h"
+#include "reiserfs_lib.h"
+
+#include "../version.h"
 
 #if __GLIBC__ >= 2
 #include <sys/mount.h>
@@ -22,13 +19,10 @@
 #include <linux/fs.h>
 #endif
 
+#include <errno.h>
+#include <string.h>
 
-#include "io.h"
-#include "misc.h"
-#include "reiserfs_lib.h"
-#include "../include/config.h"
-#include "../version.h"
-
+#include <mntent.h>
 
 #define print_usage_and_exit() {\
  fprintf (stderr, "Usage: %s  [-s[+|-]#[G|M|K]] [-fqvV] device\n\n", argv[0]);\
@@ -38,8 +32,8 @@
 #define DIE(form, args...) die("%s: " form "\n", g_progname , ## args)
 
 /* reiserfs_resize.c */
-extern struct buffer_head * g_sb_bh;
-extern char * g_progname;
+extern struct buffer_head *g_sb_bh;
+extern char *g_progname;
 
 extern int opt_force;
 extern int opt_verbose;
@@ -47,7 +41,7 @@ extern int opt_nowrite;
 extern int opt_safe;
 
 /* fe.c */
-extern int resize_fs_online(char * devname, long long int blocks);
+extern int resize_fs_online(char *devname, long long int blocks);
 
 /* do_shrink.c */
-extern int shrink_fs(reiserfs_filsys_t *, long long int blocks);
+extern int shrink_fs(reiserfs_filsys_t , long long int blocks);
